"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.builder = exports.desc = exports.aliases = exports.command = void 0;
const helpers_1 = require("../../../helpers");
// tslint:disable-next-line: no-var-requires
const logger = helpers_1.createNewLogger('codefresh:delete:webhook');
exports.command = 'webhook';
exports.aliases = ['wh', 'hook'];
exports.desc = 'Delete a git repository webhook';
exports.builder = (yargs) => yargs
    .usage('Usage: $0 delete webhook [options]')
    .option('owner', {
    alias: 'o',
    demandOption: helpers_1.errormsg `must provide "owner" option`,
    describe: 'The name of the owner of the git repository',
    type: 'string'
})
    .option('repo', {
    alias: 'r',
    demandOption: helpers_1.errormsg `must provide "repo" option`,
    describe: 'The name of the git repository',
    type: 'string'
})
    .option('hook-id', {
    alias: ['id'],
    demandOption: helpers_1.errormsg `must provide "hook-id" option`,
    describe: 'The git webhook id (returned when creating the webhook)',
    type: 'number'
})
    .example(`$0 delete ${exports.command} -o some-owner -r some-repo --id someid`, 'Will delete a webhook for repo: "some-owner/some-repo with the id: "someid"');
exports.handler = async (argv) => {
    const owner = argv.owner;
    const repo = argv.repo;
    const hookId = argv.hookId;
    const provider = argv.provider;
    logger.debug(`owner=${owner}`);
    logger.debug(`repo=${repo}`);
    logger.debug(`id=${hookId}`);
    const [err] = await helpers_1.to(provider.deleteRepositoryWebhook({ owner, repo, hookId }));
    if (err) {
        helpers_1.exitWithError(`failed to delete webhook "${hookId}" for repository: "${owner}/${repo}", ${err}`);
    }
    console.log(`successfully delete webhook "${hookId}" from repository: "${owner}/${repo}"`);
};
//# sourceMappingURL=webhook.cmd.js.map