"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.handler = exports.builder = exports.desc = exports.aliases = exports.command = void 0;
const helpers_1 = require("../../../helpers");
const logger = helpers_1.createNewLogger('codefresh:get:repo');
exports.command = 'repository';
exports.aliases = ['repo'];
exports.desc = 'Get git repository details';
exports.builder = (yargs) => yargs
    .usage('Usage: $0 get repository [options]')
    .option('owner', {
    alias: 'o',
    demandOption: helpers_1.errormsg `must provide "owner" option`,
    describe: 'The name of the owner of the git repository',
    type: 'string'
})
    .option('repo', {
    alias: 'r',
    demandOption: helpers_1.errormsg `must provide "repo" option`,
    describe: 'The name of the git repository',
    type: 'string'
})
    .example(`$0 get ${exports.command} -o some-owner -r some-repo`, 'Will return the details of a repository named "some-repo" owned by: "some-owner"');
exports.handler = async (argv) => {
    const owner = argv.owner;
    const repo = argv.repo;
    const provider = argv.provider;
    const output = argv.output;
    logger.debug(`owner=${owner}`);
    logger.debug(`repo=${repo}`);
    logger.debug(`output=${output}`);
    const [getRepoErr, repoRes] = await helpers_1.to(provider.getRepository({ owner, repo }));
    if (getRepoErr) {
        helpers_1.exitWithError(`failed to get repository "${owner}/${repo}", ${getRepoErr}`);
    }
    if (output) {
        await helpers_1.writeResultsToFile(output, repoRes);
    }
    else {
        console.log(JSON.stringify(repoRes));
    }
};
//# sourceMappingURL=repo.cmd.js.map