export declare type ProviderConstructor = new (opt: {
    password: string;
    username?: string;
    isPrivateToken?: boolean;
    refreshToken?: string;
    type: 'basic' | 'oauth2' | 'PAT';
    apiPathPrefix?: string;
    apiHost?: string;
    apiURL?: string;
    timeout?: number;
    expires?: number;
    insecure?: boolean;
}) => Provider;
export declare type ProviderName = 'github' | 'bitbucket' | 'gitlab' | 'bitbucket-server';
export declare type CommitStatus = 'pending' | 'running' | 'success' | 'failure' | 'error';
export interface Provider {
    getName(): ProviderName;
    fetchRawFile(opt: {
        owner: string;
        repo: string;
        ref: string;
        path: string;
    }): Promise<string>;
    getBranch(opt: {
        owner: string;
        repo: string;
        branch: string;
    }): Promise<Branch>;
    getRepository(opt: {
        owner: string;
        repo: string;
    }): Promise<Repository>;
    listBranches(opt: {
        owner: string;
        repo: string;
        limit?: number;
        page?: number;
    }): Promise<Branch[]>;
    listRepositoriesForOwner(opt: {
        owner: string;
        sort?: 'name' | 'pushed' | 'created';
        direction?: 'desc' | 'asc';
        limit?: number;
        page?: number;
    }): Promise<Repository[]>;
    listRepositoriesForOrganization(opt: {
        organization: string;
        sort?: 'name' | 'pushed' | 'created';
        direction?: 'desc' | 'asc';
        limit?: number;
        page?: number;
    }): Promise<Repository[]>;
    listRepositoriesWithAffiliation(opt: {
        affiliation: string;
        sort?: 'name' | 'pushed' | 'created';
        direction?: 'desc' | 'asc';
        limit?: number;
        page?: number;
    }): Promise<Repository[]>;
    listWebhooks(opt: {
        owner: string;
        repo: string;
        limit?: number;
        page?: number;
    }): Promise<Webhook[]>;
    listOrganizations(opt: {
        limit?: number;
        page?: number;
    }): Promise<string[]>;
    createRepositoryWebhook(opt: {
        owner: string;
        repo: string;
        endpoint: string;
        secret: string;
    }): Promise<Webhook>;
    createCommitStatus(opt: {
        owner: string;
        repo: string;
        sha: string;
        targetUrl: string;
        state: CommitStatus;
        description: string;
        context: string;
    }): Promise<void>;
    deleteRepositoryWebhook(opt: {
        owner: string;
        repo: string;
        hookId: number;
    }): Promise<void>;
}
export interface Repository {
    id: string;
    provider: ProviderName;
    name: string;
    full_name: string;
    private: boolean;
    pushed_at: Date;
    open_issues: number;
    clone_url: string;
    ssh_url: string;
    owner: {
        login: string;
        avatar_url: string;
        creator: string | null;
    };
    org?: string | null;
    default_branch: string;
    permissions: {
        admin: boolean | null;
    };
    webUrl: string;
    project?: string;
}
export interface Branch {
    name: string;
    id: string;
    commit: Commit;
}
export interface Commit {
    sha: string;
    message?: string;
    commiter_name?: string;
    url?: string;
}
export interface Webhook {
    id: string;
    name: string;
    events: string[];
    endpoint: string;
    repo: string;
}
